## GCP-JWT
GCP-JWT is a library to create and sign tokens using the Google Cloud 
Platform's Key Management Service. It handles the signing and verification
of the token.

### Key Features
* [x] Token Signage
* [x] Signature Verification
* [x] Expiry Verification
---
* [ ] Auto Rotating Asymmetric Key
* [ ] Batch Token Generation
* [ ] Pretty API

### Install
**Using PIP :**
``pip install gcp-jwt``